==> 0.3.1.tar.gz: lib/bloc/common_widgets/recharge_card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:loyalty_management_tool/bloc/common_widgets/recharge_wallet_coin.dart';
import 'package:loyalty_management_tool/models/enums/payments_enums.dart';

import '../../utils/app_buttons.dart';
import '../../utils/basicInfo.dart';
import '../../utils/colors.dart';
import '../../utils/common_helpdesk_sheet.dart';
import '../../utils/hexColors.dart';
import '../../utils/localization.dart';
import '../../utils/text_styling.dart';
import '../cubits/cubit_main.dart';
import '../rewards_module/pages/payment_screen.dart';

// ignore: must_be_immutable
class RechargeWalletCard extends StatelessWidget {
  int? userId;
  String? userName;
  String? userType;
  String textOne;
  String textTwo;
  String textThree;
  String textFour;
  String textFive;
  String textSix;
  String textSeven;
  String textEight;
  int? ownerId;
  String? ownerType;
  Null Function()? callback;
  String? businessId;
  String? imageurl;
  final String type;
final Function refreshCallBack;
  RechargeWalletCard(
      {Key? key,
      required this.type,
        required this.refreshCallBack,
      required this.textOne,
      required this.textTwo,
      required this.textThree,
      required this.textFour,
      required this.textFive,
      required this.textSix,
      required this.textSeven,
      required this.textEight,
      this.userId,
      this.ownerId,
      this.ownerType,
      this.userName,
      this.imageurl,
      this.businessId,
      required this.callback,
      this.userType})
      : super(key: key);
  late TextStyleElements styleElements;
  BasicInfo? basicInfo = BasicInfo();
  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      color: HexColor(AppColors.appColorWhite),
      child: Align(
          alignment: Alignment.centerLeft,
          child: Row(children: <Widget>[
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: GestureDetector(
                  onTap: () {
                    /* Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => CourseDetailPage(
                            id: null,

                            */ /* userType: "staff",*/ /*
                          ),
                        ));*/
                  },
                  child: GestureDetector(
                    behavior: HitTestBehavior.translucent,
                    child: Column(
                      children: <Widget>[
                        Container(
                          margin: EdgeInsets.all(2.h),
                          child: Text(
                            textFive,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                                    fontWeight: FontWeight.bold,
                                    color: HexColor(AppColors.appColorBlack85)),
                            textAlign: TextAlign.left,
                          ),
                        ),
                        Container(
                          margin: EdgeInsets.only(
                              bottom: 2.h, left: 2.h, right: 2.h),
                          child: Text(
                            textOne,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements.captionThemeScalable(context),
                            textAlign: TextAlign.left,
                          ),
                        ),
                      ],
                    ),
                    onTap: () async {},
                  )),
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: GestureDetector(
                  behavior: HitTestBehavior.translucent,
                  onTap: () async {},
                  child: Column(
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.all(2.h),
                        child: Text(
                          textSix,
                          overflow: TextOverflow.ellipsis,
                          style: styleElements
                              .subtitle2ThemeScalable(context)
                              .copyWith(
                                  fontWeight: FontWeight.bold,
                                  color: HexColor(AppColors.appColorBlack85)),
                          textAlign: TextAlign.left,
                        ),
                      ),
                      Container(
                        margin:
                            EdgeInsets.only(bottom: 2.h, left: 2.h, right: 2.h),
                        child: Text(
                          textTwo,
                          overflow: TextOverflow.ellipsis,
                          style: styleElements.captionThemeScalable(context),
                          textAlign: TextAlign.left,
                        ),
                      ),
                    ],
                  )),
            ),
            Expanded(
                child: Align(
              alignment: Alignment.centerRight,
              child: appElevatedButton(
                  elevation: 0,
                  shape: StadiumBorder(
                      side:
                          BorderSide(color: HexColor(AppColors.appColorWhite))),
                  onPressed: () {
                    showModalBottomSheet(
                      context: context,
                      isScrollControlled: true,
                      shape: const RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                              topLeft: Radius.circular(12),
                              topRight: Radius.circular(12))),
                      builder: (BuildContext context) {
                        return Wrap(
                          children: [
                            CommonHelpdeskSheet(
                              child: BlocProvider(
                                create: (_) => CubitMain(),
                                child: RechargeWalletCoins(
                                  type: type,
                                refreshCallBack:refreshCallBack,
                                  firstItemHint:
                                      AppLocalizationsRewards.of(context)!
                                          .translate(
                                              type == PaymentEnums.cash.type
                                                  ? 'cash'
                                                  : 'coins'),
                                  firstItemTag:
                                      AppLocalizationsRewards.of(context)!
                                          .translate(
                                              type == PaymentEnums.cash.type
                                                  ? 'cas_amount'
                                                  : "c_amount"),
                                  firstItemIcon:  Icon(
                                    Icons.currency_bitcoin,
                                    color: HexColor(AppColors.appMainColor),
                                  ),
                                  title: AppLocalizationsRewards.of(context)!
                                      .translate(type == PaymentEnums.cash.type
                                          ? "recharge_wallet"
                                          : 'recharge_coin'),
                                  nextCallBack: (data) {

                                    Navigator.pop(context);
                                    Navigator.push(
                                        context,
                                        MaterialPageRoute(
                                          builder: (context) => BlocProvider(
                                            create: (_) => CubitMain(),
                                            child: PaymentPage(
                                                type: type,
                                                data:data,
                                                title:
                                                    AppLocalizationsRewards.of(
                                                            context)!
                                                        .translate(type ==
                                                                PaymentEnums
                                                                    .cash.type
                                                            ? "cash_wallet"
                                                            : 'coin_wallet')),
                                          ),
                                        ));
                                  },
                                  subTitle: AppLocalizationsRewards.of(context)!
                                      .translate(type == PaymentEnums.cash.type
                                          ? "r_des_wallet"
                                          : 'r_des'),
                                ),
                              ),
                            ),
                          ],
                        );
                      },
                    );
                  },
                  child: Text(
                    "Recharge",
                    style: styleElements
                        .captionThemeScalable(context)
                        .copyWith(color: HexColor(AppColors.appColorWhite)),
                  ),
                  color: HexColor(AppColors.appMainColor)),
            )),
          ])),
    );
  }

  void update(updateFollowers) {
    callback!();
  }
}

==> 0.4.1.tar.gz: lib/bloc/common_widgets/recharge_card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:loyalty_management_tool/bloc/common_widgets/recharge_wallet_coin.dart';
import 'package:loyalty_management_tool/models/enums/payments_enums.dart';

import '../../utils/app_buttons.dart';
import '../../utils/basicInfo.dart';
import '../../utils/colors.dart';
import '../../utils/common_helpdesk_sheet.dart';
import '../../utils/hexColors.dart';
import '../../utils/localization.dart';
import '../../utils/text_styling.dart';
import '../cubits/cubit_main.dart';
import '../rewards_module/pages/payment_screen.dart';

// ignore: must_be_immutable
class RechargeWalletCard extends StatelessWidget {
  int? userId;
  String? userName;
  String? userType;
  String textOne;
  String textTwo;
  String textThree;
  String textFour;
  String textFive;
  String textSix;
  String textSeven;
  String textEight;
  int? ownerId;
  String? ownerType;
  Null Function()? callback;
  String? businessId;
  String? imageurl;
  final String type;
final Function refreshCallBack;
  RechargeWalletCard(
      {Key? key,
      required this.type,
        required this.refreshCallBack,
      required this.textOne,
      required this.textTwo,
      required this.textThree,
      required this.textFour,
      required this.textFive,
      required this.textSix,
      required this.textSeven,
      required this.textEight,
      this.userId,
      this.ownerId,
      this.ownerType,
      this.userName,
      this.imageurl,
      this.businessId,
      required this.callback,
      this.userType})
      : super(key: key);
  late TextStyleElements styleElements;
  BasicInfo? basicInfo = BasicInfo();
  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Container(
      color: HexColor(AppColors.appColorWhite),
      child: Align(
          alignment: Alignment.centerLeft,
          child: Row(children: <Widget>[
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: GestureDetector(
                  onTap: () {
                    /* Navigator.push(
                        context,
                        MaterialPageRoute(
                          builder: (context) => CourseDetailPage(
                            id: null,

                            */ /* userType: "staff",*/ /*
                          ),
                        ));*/
                  },
                  child: GestureDetector(
                    behavior: HitTestBehavior.translucent,
                    child: Column(
                      children: <Widget>[
                        Container(
                          margin: EdgeInsets.all(2),
                          child: Text(
                            textFive,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements
                                .subtitle2ThemeScalable(context)
                                .copyWith(
                                    fontWeight: FontWeight.bold,
                                    color: HexColor(AppColors.appColorBlack85)),
                            textAlign: TextAlign.left,
                          ),
                        ),
                        Container(
                          margin: EdgeInsets.only(
                              bottom: 2, left: 2, right: 2),
                          child: Text(
                            textOne,
                            overflow: TextOverflow.ellipsis,
                            style: styleElements.captionThemeScalable(context),
                            textAlign: TextAlign.left,
                          ),
                        ),
                      ],
                    ),
                    onTap: () async {},
                  )),
            ),
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: GestureDetector(
                  behavior: HitTestBehavior.translucent,
                  onTap: () async {},
                  child: Column(
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.all(2),
                        child: Text(
                          textSix,
                          overflow: TextOverflow.ellipsis,
                          style: styleElements
                              .subtitle2ThemeScalable(context)
                              .copyWith(
                                  fontWeight: FontWeight.bold,
                                  color: HexColor(AppColors.appColorBlack85)),
                          textAlign: TextAlign.left,
                        ),
                      ),
                      Container(
                        margin:
                            EdgeInsets.only(bottom: 2, left: 2, right: 2),
                        child: Text(
                          textTwo,
                          overflow: TextOverflow.ellipsis,
                          style: styleElements.captionThemeScalable(context),
                          textAlign: TextAlign.left,
                        ),
                      ),
                    ],
                  )),
            ),
            Expanded(
                child: Align(
              alignment: Alignment.centerRight,
              child: appElevatedButton(
                  elevation: 0,
                  shape: StadiumBorder(
                      side:
                          BorderSide(color: HexColor(AppColors.appColorWhite))),
                  onPressed: () {
                    showModalBottomSheet(
                      context: context,
                      isScrollControlled: true,
                      shape: const RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                              topLeft: Radius.circular(12),
                              topRight: Radius.circular(12))),
                      builder: (BuildContext context) {
                        return Wrap(
                          children: [
                            CommonHelpdeskSheet(
                              child: BlocProvider(
                                create: (_) => CubitMain(),
                                child: RechargeWalletCoins(
                                  type: type,
                                refreshCallBack:refreshCallBack,
                                  firstItemHint:
                                      AppLocalizationsRewards.of(context)!
                                          .translate(
                                              type == PaymentEnums.cash.type
                                                  ? 'cash'
                                                  : 'coins'),
                                  firstItemTag:
                                      AppLocalizationsRewards.of(context)!
                                          .translate(
                                              type == PaymentEnums.cash.type
                                                  ? 'cas_amount'
                                                  : "c_amount"),
                                  firstItemIcon:  Icon(
                                    Icons.currency_bitcoin,
                                    color: HexColor(AppColors.appMainColor),
                                  ),
                                  title: AppLocalizationsRewards.of(context)!
                                      .translate(type == PaymentEnums.cash.type
                                          ? "recharge_wallet"
                                          : 'recharge_coin'),
                                  nextCallBack: (data) {


                                    Navigator.pop(context);
                                    Navigator.push(
                                        context,
                                        MaterialPageRoute(
                                          builder: (context) => BlocProvider(
                                            create: (_) => CubitMain(),
                                            child: PaymentPage(
                                                type: type,
                                                data:data,
                                                title:
                                                    AppLocalizationsRewards.of(
                                                            context)!
                                                        .translate(type ==
                                                                PaymentEnums
                                                                    .cash.type
                                                            ? "cash_wallet"
                                                            : 'coin_wallet')),
                                          ),
                                        ));
                                  },
                                  subTitle: AppLocalizationsRewards.of(context)!
                                      .translate(type == PaymentEnums.cash.type
                                          ? "r_des_wallet"
                                          : 'r_des'),
                                ),
                              ),
                            ),
                          ],
                        );
                      },
                    );
                  },
                  child: Text(
                    "Recharge",
                    style: styleElements
                        .captionThemeScalable(context)
                        .copyWith(color: HexColor(AppColors.appColorWhite)),
                  ),
                  color: HexColor(AppColors.appMainColor)),
            )),
          ])),
    );
  }

  void update(updateFollowers) {
    callback!();
  }
}
